from distutils.core import setup
setup(
  name='germantournament',
  packages=['germantournament'],  # this must be the same as the name above
  version='0.1',
  description='A package for help schedule tournaments',
  author='Orcun Gumus',
  author_email='orcungumus@gmail.com',
  url='https://github.com/guemues/german-game-tournament',  # use the URL to the github repo
  download_url='https://github.com/guemues/german-game-tournament/archive/0.1.tar.gz',  # I'll explain this in a second
  keywords=['tournament', 'german', 'game'],  # arbitrary keywords
  classifiers=[],
)